@@ -1,10 +1,9 @@
 package Net::DNS::Header;
 
 #
-# $Id: Header.pm 1367 2015-06-29 08:53:56Z willem $
+# $Id: Header.pm 1709 2018-09-07 08:03:09Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1367 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1709 $)[1];
 
 
 =head1 NAME
@@ -27,6 +26,7 @@ C<Net::DNS::Header> represents the header portion of a DNS packet.
 
 
 use strict;
+use warnings;
 use integer;
 use Carp;
 
@@ -70,7 +70,7 @@ sub string {
 	my $ar	   = $self->arcount;
 
 	my $opt = $$self->edns;
-	my $edns = $opt->defined ? $opt->string : '';
+	my $edns = $opt->_specified ? $opt->string : '';
 
 	return <<END . $edns if $opcode eq 'UPDATE';
 ;;	id = $id
@@ -163,7 +163,7 @@ sub rcode {
 		my $opt = $$self->edns;
 		unless ( defined $arg ) {
 			my $rcode = $opt->rcode;
-			return rcodebyval( $_ & 0x0f ) unless $opt->defined;
+			return rcodebyval( $_ & 0x0f ) unless $opt->_specified;
 			$rcode = ( $rcode & 0xff0 ) | ( $_ & 0x00f );
 			$opt->rcode($rcode);			# write back full 12-bit rcode
 			return $rcode == 16 ? 'BADVERS' : rcodebyval($rcode);
@@ -193,7 +193,7 @@ sub qr {
 
 =head2 aa
 
-    print "answer is ", $packet->header->aa ? "" : "non-", "authoritative\n";
+    print "response is ", $packet->header->aa ? "" : "non-", "authoritative\n";
     $packet->header->aa(0);
 
 Gets or sets the authoritative answer flag.
@@ -260,11 +260,11 @@ sub z {
 
 =head2 ad
 
-    print "The result has ", $packet->header->ad ? "" : "not", "been verified\n";
+    print "The response has ", $packet->header->ad ? "" : "not", "been verified\n";
 
 Relevant in DNSSEC context.
 
-(The AD bit is only set on answers where signatures have been
+(The AD bit is only set on a response where signatures have been
 cryptographically verified or the server is authoritative for the data
 and is allowed to set the bit by policy.)
 
@@ -299,7 +299,7 @@ to the number of RRs in the zone section.
 
 =cut
 
-use vars qw($warned);
+our $warned;
 
 sub qdcount {
 	my $self = shift;
