@@ -1,9 +1,9 @@
 package Net::DNS::RR::CDNSKEY;
 
 #
-# $Id: CDNSKEY.pm 1580 2017-06-26 11:44:49Z willem $
+# $Id: CDNSKEY.pm 1586 2017-08-15 09:01:57Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1580 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1586 $)[1];
 
 
 use strict;
@@ -20,28 +20,18 @@ Net::DNS::RR::CDNSKEY - DNS CDNSKEY resource record
 use integer;
 
 
-sub _encode_rdata {			## encode rdata as wire-format octet string
-	my $self = shift;
-
-	return $self->SUPER::_encode_rdata() if $self->{algorithm};
-	return defined $self->{algorithm} ? pack( 'xxH*x', '03' ) : '';
-}
-
-
-sub _format_rdata {			## format rdata portion of RR string.
-	my $self = shift;
-
-	return $self->SUPER::_format_rdata() if $self->{algorithm};
-	return defined $self->{algorithm} ? '0 3 0 0' : '';
-}
-
-
 sub algorithm {
 	my ( $self, $arg ) = @_;
-
 	return $self->SUPER::algorithm($arg) if $arg;
-	@{$self}{qw(flags protocol algorithm keybin)} = ( 0, 3, 0, '' ) if defined $arg;
-	return $self->SUPER::algorithm();
+	return $self->SUPER::algorithm() unless defined $arg;
+	@{$self}{qw(flags protocol algorithm)} = ( 0, 3, 0 );
+}
+
+
+sub key {
+	my $self = shift;
+	return $self->SUPER::key(@_) unless defined( $_[0] ) && length( $_[0] ) < 2;
+	return $self->SUPER::keybin( $_[0] ? '' : chr(0) );
 }
 
 
@@ -104,6 +94,6 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, L<Net::DNS::RR::DNSKEY>, RFC7344, RFC8087
+L<perl>, L<Net::DNS>, L<Net::DNS::RR>, L<Net::DNS::RR::DNSKEY>, RFC7344, RFC8078(erratum 5049)
 
 =cut
