@@ -1,13 +1,13 @@
 package Net::DNS::RR::TKEY;
 
 #
-# $Id: TKEY.pm 1406 2015-10-05 08:25:49Z willem $
+# $Id: TKEY.pm 1528 2017-01-18 21:44:58Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1406 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1528 $)[1];
 
 
 use strict;
+use warnings;
 use base qw(Net::DNS::RR);
 
 =head1 NAME
